
BEGIN {
  unless ($ENV{AUTHOR_TESTING}) {
    print qq{1..0 # SKIP these tests are for testing by the author\n};
    exit
  }
}

use strict;
use warnings;
use Test::More;

# generated by Dist::Zilla::Plugin::Test::PodSpelling 2.007004
use Test::Spelling 0.12;
use Pod::Wordlist;


add_stopwords(<DATA>);
all_pod_files_spelling_ok( qw( bin lib ) );
__DATA__
API
Ack
Alders
Alders'
Anwar
Aronesty
AuthorizationID
AuthorizationRequest
AuthorizeRequest
BillingAgreement
Bourne
Bowers
Bradley
Business
Böhm
CDATA
CaptureRequest
CertFile
CompleteType
Daniel
Danny
Dave
David
DirectPayment
DirectPayments
DoDirectPaymentRequest
DoExpressCheckoutPayment
DoReauthorization
DoReauthorizationRequest
DoReferenceTransaction
DoVoidRequest
Doran
ExpressCheckout
GetBalance
GetExpressCheckoutDetails
GetTransactionDetails
Gregory
GrossAmount
Hembree
KeyFile
Kuhn
Lambley
Lindley
Marco
MassPay
MassPayItem
Mohammad
Neil
Olaf
Oschwald
PEM
PKCS
PayPal
PaymentItem
PaymentItems
Pessotto
Phipps
ReAuthorizationRequest
ReauthorizationRequest
RecurringPayments
RefundTransaction
RefundType
ReturnURL
Ron
SDC
SOM
Scott
SetExpressCheckout
ShippingTotal
Spiegl
StartDate
Steinbrunner
Tomas
TransactionID
TransactionSearch
USD
UniqueId
VoidRequest
WPP
WSDL
Wiersdorf
William
auth
billers
bkuhn
currencyID
danny
daught
davel
derivates
drjays
dsteinbrunner
eg
goschwald
lib
melmothx
mohammad
ndrix
neil
olaf
ron
scott
t0m
wlindley
